@@ -1,11 +1,12 @@
 /* Declarations for FTP support.
-   Copyright (C) 1995, 1996, 1997, 2000 Free Software Foundation, Inc.
+   Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003,
+   2004, 2005, 2006, 2007, 2008 Free Software Foundation, Inc.
 
 This file is part of GNU Wget.
 
 GNU Wget is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
+the Free Software Foundation; either version 3 of the License, or
 (at your option) any later version.
 
 GNU Wget is distributed in the hope that it will be useful,
@@ -14,18 +15,18 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with Wget; if not, write to the Free Software
-Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+along with Wget.  If not, see <http://www.gnu.org/licenses/>.
 
-In addition, as a special exception, the Free Software Foundation
-gives permission to link the code of its release of Wget with the
-OpenSSL project's "OpenSSL" library (or with modified versions of it
-that use the same license as the "OpenSSL" library), and distribute
-the linked executables.  You must obey the GNU General Public License
-in all respects for all of the code used other than "OpenSSL".  If you
-modify this file, you may extend this exception to your version of the
-file, but you are not obligated to do so.  If you do not wish to do
-so, delete this exception statement from your version.  */
+Additional permission under GNU GPL version 3 section 7
+
+If you modify this program, or any covered work, by linking or
+combining it with the OpenSSL project's OpenSSL library (or a
+modified version of that library), containing parts covered by the
+terms of the OpenSSL or SSLeay licenses, the Free Software Foundation
+grants you additional permission to convey the resulting work.
+Corresponding Source for a non-source form of such a combination
+shall include the source code for the parts of OpenSSL used as well
+as that of the covered work.  */
 
 #ifndef FTP_H
 #define FTP_H
@@ -42,28 +43,30 @@ enum stype
   ST_OS400,
   ST_OTHER
 };
-  
-uerr_t ftp_response PARAMS ((int, char **));
-uerr_t ftp_login PARAMS ((int, const char *, const char *));
-uerr_t ftp_port PARAMS ((int, int *));
-uerr_t ftp_pasv PARAMS ((int, ip_address *, int *));
+
+extern char ftp_last_respline[];
+
+uerr_t ftp_response (int, char **);
+uerr_t ftp_login (int, const char *, const char *);
+uerr_t ftp_port (int, int *);
+uerr_t ftp_pasv (int, ip_address *, int *);
 #ifdef ENABLE_IPV6
-uerr_t ftp_lprt PARAMS ((int, int *));
-uerr_t ftp_lpsv PARAMS ((int, ip_address *, int *));
-uerr_t ftp_eprt PARAMS ((int, int *));
-uerr_t ftp_epsv PARAMS ((int, ip_address *, int *));
+uerr_t ftp_lprt (int, int *);
+uerr_t ftp_lpsv (int, ip_address *, int *);
+uerr_t ftp_eprt (int, int *);
+uerr_t ftp_epsv (int, ip_address *, int *);
 #endif
-uerr_t ftp_type PARAMS ((int, int));
-uerr_t ftp_cwd PARAMS ((int, const char *));
-uerr_t ftp_retr PARAMS ((int, const char *));
-uerr_t ftp_rest PARAMS ((int, wgint));
-uerr_t ftp_list PARAMS ((int, const char *));
-uerr_t ftp_syst PARAMS ((int, enum stype *));
-uerr_t ftp_pwd PARAMS ((int, char **));
-uerr_t ftp_size PARAMS ((int, const char *, wgint *));
+uerr_t ftp_type (int, int);
+uerr_t ftp_cwd (int, const char *);
+uerr_t ftp_retr (int, const char *);
+uerr_t ftp_rest (int, wgint);
+uerr_t ftp_list (int, const char *);
+uerr_t ftp_syst (int, enum stype *);
+uerr_t ftp_pwd (int, char **);
+uerr_t ftp_size (int, const char *, wgint *);
 
 #ifdef ENABLE_OPIE
-const char *skey_response PARAMS ((int, const char *, const char *));
+const char *skey_response (int, const char *, const char *);
 #endif
 
 struct url;
@@ -116,12 +119,12 @@ enum wget_ftp_fstatus
 				   correct.  */
 };
 
-struct fileinfo *ftp_parse_ls PARAMS ((const char *, const enum stype));
-uerr_t ftp_loop PARAMS ((struct url *, int *, struct url *));
+struct fileinfo *ftp_parse_ls (const char *, const enum stype);
+uerr_t ftp_loop (struct url *, int *, struct url *, bool, bool);
 
-uerr_t ftp_index PARAMS ((const char *, struct url *, struct fileinfo *));
+uerr_t ftp_index (const char *, struct url *, struct fileinfo *);
 
-char ftp_process_type PARAMS ((const char *));
+char ftp_process_type (const char *);
 
 
 #endif /* FTP_H */
