@@ -1,12 +1,12 @@
 /* Declarations for windows
-   Copyright (C) 1995, 1997, 1997, 1998, 2004
-   Free Software Foundation, Inc.
+   Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003,
+   2004, 2005, 2006, 2007, 2008 Free Software Foundation, Inc.
 
 This file is part of GNU Wget.
 
 GNU Wget is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
+the Free Software Foundation; either version 3 of the License, or
 (at your option) any later version.
 
 GNU Wget is distributed in the hope that it will be useful,
@@ -15,37 +15,37 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with Wget; if not, write to the Free Software
-Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+along with Wget.  If not, see <http://www.gnu.org/licenses/>.
 
-In addition, as a special exception, the Free Software Foundation
-gives permission to link the code of its release of Wget with the
-OpenSSL project's "OpenSSL" library (or with modified versions of it
-that use the same license as the "OpenSSL" library), and distribute
-the linked executables.  You must obey the GNU General Public License
-in all respects for all of the code used other than "OpenSSL".  If you
-modify this file, you may extend this exception to your version of the
-file, but you are not obligated to do so.  If you do not wish to do
-so, delete this exception statement from your version.  */
+Additional permission under GNU GPL version 3 section 7
+
+If you modify this program, or any covered work, by linking or
+combining it with the OpenSSL project's OpenSSL library (or a
+modified version of that library), containing parts covered by the
+terms of the OpenSSL or SSLeay licenses, the Free Software Foundation
+grants you additional permission to convey the resulting work.
+Corresponding Source for a non-source form of such a combination
+shall include the source code for the parts of OpenSSL used as well
+as that of the covered work.  */
 
 #ifndef MSWINDOWS_H
 #define MSWINDOWS_H
 
 #ifndef WGET_H
-#error Include mswindows.h inside or after "wget.h"
+# error This file should not be included directly.
 #endif
 
 /* Prevent inclusion of <winsock*.h> in <windows.h>.  */
 #ifndef WIN32_LEAN_AND_MEAN
-#define WIN32_LEAN_AND_MEAN
+# define WIN32_LEAN_AND_MEAN
 #endif
 
 #include <windows.h>
 
-/* Use the correct winsock header; <ws2tcpip.h> includes <winsock2.h> only
-   on Watcom/MingW.  We cannot use <winsock.h> for IPv6.  Using
-   getaddrinfo() requires <ws2tcpip.h>.  */
-#if defined(ENABLE_IPV6) || defined(HAVE_GETADDRINFO)
+/* We need winsock2.h for IPv6 and ws2tcpip.h for getaddrinfo, so
+  include both in ENABLE_IPV6 case.  (ws2tcpip.h includes winsock2.h
+  only on MinGW.) */
+#ifdef ENABLE_IPV6
 # include <winsock2.h>
 # include <ws2tcpip.h>
 #else
@@ -56,14 +56,12 @@ so, delete this exception statement from your version.  */
 # define EAI_SYSTEM -1   /* value doesn't matter */
 #endif
 
-/* Must include <sys/stat.h> because of 'stat' define below.  */
-#include <sys/stat.h>
-
-/* Missing in several .c files.  Include here.  */
+/* Declares file access functions, such as open, creat, access, and
+   chmod.  Unix declares these in unistd.h and fcntl.h.  */
 #include <io.h>
 
-/* Apparently needed for alloca().  */
-#include <malloc.h>
+/* Declares getpid(). */
+#include <process.h>
 
 #ifndef S_ISDIR
 # define S_ISDIR(m) (((m) & (_S_IFMT)) == (_S_IFDIR))
@@ -72,9 +70,13 @@ so, delete this exception statement from your version.  */
 # define S_ISLNK(a) 0
 #endif
 
-/* We have strcasecmp and strncasecmp, just under a different name.  */
-#define strcasecmp stricmp
-#define strncasecmp strnicmp
+/* We have strcasecmp and strncasecmp, just under different names.  */
+#ifndef HAVE_STRCASECMP
+# define strcasecmp stricmp
+#endif
+#ifndef HAVE_STRNCASECMP
+# define strncasecmp strnicmp
+#endif
 
 /* The same for snprintf() and vsnprintf().  */
 #define snprintf _snprintf
@@ -84,69 +86,49 @@ so, delete this exception statement from your version.  */
 typedef __int64 wgint;
 #define SIZEOF_WGINT 8
 
-#ifdef __GNUC__
-#define WGINT_MAX 9223372036854775807LL
-#else
-#define WGINT_MAX 9223372036854775807I64
-#endif
-
-#if defined __MINGW32__
+/* str_to_wgint is a function with the semantics of strtol[l], but
+   which works on wgint.  */
+#if defined HAVE_STRTOLL
 # define str_to_wgint strtoll
-#elif defined(_MSC_VER) && _MSC_VER >= 1300 && !defined(__BORLANDC__)
+#elif defined HAVE__STRTOI64
 # define str_to_wgint _strtoi64
 #else
 # define str_to_wgint strtoll
 # define NEED_STRTOLL
-# define strtoll_return __int64
+# define strtoll_type __int64
 #endif
 
 /* Windows has no symlink, therefore no lstat.  Without symlinks lstat
    is equivalent to stat anyway.  */
 #define lstat stat
 
-/* Transparently support statting large files, like POSIX's LFS API
-   does.  All Windows compilers we support use _stati64 (but have
-   different names for 2nd argument type, see below), so we use
-   that.  */
-#define stat(fname, buf) _stati64 (fname, buf)
-
-/* On Windows the 64-bit stat requires an explicitly different type
-   for the 2nd argument, so we define a struct_stat macro that expands
-   to the appropriate type on Windows, and to the regular struct stat
-   on Unix.
-
-   Note that Borland C 5.5 has 64-bit stat (_stati64), but not a
-   64-bit fstat!  Because of that we also need a struct_fstat that
-   points to struct_stat on Unix and on Windows, except under Borland,
-   where it points to the 32-bit struct stat.  */
-
-#ifndef __BORLANDC__
-# define fstat(fd, buf) _fstati64 (fd, buf)
-# define struct_stat  struct _stati64
-# define struct_fstat struct _stati64
-#else  /* __BORLANDC__ */
-# define struct_stat  struct stati64
-# define struct_fstat struct stat
-#endif /* __BORLANDC__ */
+/* Define LFS aliases for stat and fstat. */
+#ifdef stat_alias
+# define stat(f, b) stat_alias (f, b)
+#endif
+#ifdef fstat_alias
+# define fstat(f, b) fstat_alias (f, b)
+#endif
 
 #define PATH_SEPARATOR '\\'
 
-#ifdef HAVE_ISATTY
-#ifdef _MSC_VER
-# define isatty _isatty
-#endif
-#endif
-
-/* #### Do we need this?  */
+/* Win32 doesn't support the MODE argument to mkdir.  */
 #include <direct.h>
+#define mkdir(a, b) (mkdir) (a)
 
-/* Windows compilers accept only one arg to mkdir.  */
-#define mkdir(a, b) _mkdir(a)
+/* Additional declarations needed for IPv6: */
+#ifdef ENABLE_IPV6
+const char *inet_ntop (int, const void *, char *, socklen_t);
+#endif
+
+#ifdef NEED_GAI_STRERROR
+# undef gai_strerror
+# define gai_strerror windows_strerror
+#endif
 
 #ifndef INHIBIT_WRAP
 
-/* Winsock functions don't set errno, so we provide wrappers
-   that do. */
+/* Winsock functions don't set errno, so we provide wrappers that do. */
 
 #define socket wrapped_socket
 #define bind wrapped_bind
@@ -183,13 +165,6 @@ int wrapped_closesocket (int);
 #endif
 const char *windows_strerror (int);
 
-/* MingW 3.7 (or older) prototypes gai_strerror(), but is missing
-   from all import libraries. */
-#if defined(__MINGW32__) && defined(ENABLE_IPV6)
-# undef gai_strerror
-# define gai_strerror windows_strerror
-#endif
-
 /* Declarations of various socket errors:  */
 
 #define EWOULDBLOCK             WSAEWOULDBLOCK
@@ -234,13 +209,6 @@ void ws_startup (void);
 void ws_changetitle (const char *);
 void ws_percenttitle (double);
 char *ws_mypath (void);
-void windows_main (int *, char **, char **);
-
-/* Things needed for IPv6; missing in <ws2tcpip.h>.  */
-#ifdef ENABLE_IPV6
-# ifndef HAVE_INET_NTOP
-extern const char *inet_ntop (int af, const void *src, char *dst, size_t size);
-# endif
-#endif /* ENABLE_IPV6 */
+void windows_main (char **);
 
 #endif /* MSWINDOWS_H */
